summaryrefslogtreecommitdiff
path: root/src/mongo/db/server_options.h
diff options
context:
space:
mode:
authorHenrik Edin <henrik.edin@mongodb.com>2019-10-08 21:53:47 +0000
committerevergreen <evergreen@mongodb.com>2019-10-08 21:53:47 +0000
commit40fb24a73ce0c8c1092dda3f2631648990f4587a (patch)
treede79a829b7b5147a793d122256e956c6bf112ae8 /src/mongo/db/server_options.h
parent2dc8d02b22117c2503385d8bdd434ac5cb7f7f86 (diff)
downloadmongo-40fb24a73ce0c8c1092dda3f2631648990f4587a.tar.gz
SERVER-43744 Add logFormat configure option (logv2 only)
Diffstat (limited to 'src/mongo/db/server_options.h')
-rw-r--r--src/mongo/db/server_options.h4
1 files changed, 3 insertions, 1 deletions
diff --git a/src/mongo/db/server_options.h b/src/mongo/db/server_options.h
index ed333a8ed13..f6d060837a3 100644
--- a/src/mongo/db/server_options.h
+++ b/src/mongo/db/server_options.h
@@ -30,6 +30,7 @@
#pragma once
#include "mongo/db/jsobj.h"
+#include "mongo/logv2/log_format.h"
#include "mongo/platform/atomic_word.h"
#include "mongo/platform/process_id.h"
#include "mongo/stdx/variant.h"
@@ -96,7 +97,8 @@ struct ServerGlobalParams {
std::string pidFile; // Path to pid file, or empty if none.
std::string timeZoneInfoPath; // Path to time zone info directory, or empty if none.
- std::string logpath; // Path to log file, if logging to a file; otherwise, empty.
+ std::string logpath; // Path to log file, if logging to a file; otherwise, empty.
+ logv2::LogFormat logFormat = logv2::LogFormat::kDefault; // Log format to output to
bool logAppend = false; // True if logging to a file in append mode.
bool logRenameOnRotate = true; // True if logging should rename log files on rotate
bool logWithSyslog = false; // True if logging to syslog; must not be set if logpath is set.